@@ -13,12 +13,12 @@ from mash.shell.function import LAST_RESULTS
 from mash.shell.ast import ElseCondition, Indent, Lines, Map, Math, Node, Term, Terms
 from mash.shell.base import BaseShell
 from mash.shell.cmd2 import default_prompt, run
-from mash.shell.grammer.delimiters import DEFINE_FUNCTION
+from mash.shell.grammer.literals import DEFINE_FUNCTION
 from mash.shell.errors import ShellError, ShellPipeError, ShellSyntaxError
 from mash.shell.errors import ShellSyntaxError
 from mash.shell.function import ShellFunction as Function
 from mash.shell.internals.if_statement import Abort, handle_prev_then_else_statements
-from mash.shell.grammer.lex_yacc import parse
+from mash.shell.grammer.parser import parse
 from mash.util import has_method, is_valid_method_name
 
 description = 'If no positional arguments are given then an interactive subshell is started.'
@@ -180,18 +180,6 @@ class Shell(BaseShell):
         for arg in args:
             self.onecmd(f'{f} {arg}')
 
-    def _do_foreach(self, ast: tuple, prev_results: str) -> Iterable:
-        """Apply a function to every term or word.
-
-        Usage
-        ```sh
-        echo a b |> foreach echo
-        echo a b |> foreach echo prefix $ suffix
-        ```
-        """
-        prev_results = '\n'.join(prev_results.split(' '))
-        return Map.map(ast, prev_results, self, delimiter=' ')
-
     def foldr(self, commands: List[Term], prev_results: str, delimiter='\n'):
         items = parse(prev_results).values
         k, acc, *args = commands
