@@ -7,7 +7,7 @@ import time
 import logging
 
 from mash.io_util import shell_ready_signal, has_output
-import mash.shell.progress_bar as progress_bar
+import mash.progress_bar as progress_bar
 
 is_activated = defaultdict(bool)
 
